import type { ExtendedEvent } from '../types.js';
/**
 * Use this helper to authenticate load functions, actions and request-handlers
 *
 * @example
 * export const load = withAuth(({ session, getSupabaseClient }) => {
 *  if (!session) {
 *    throw redirect(303, '/signin');
 *  }
 *  const { data: profile } = getSupabaseClient()
 *    .from('profiles')
 *    .select()
 *    .eq('user_id', session.user.id);
 *
 *  return { profile }
 * })
 */
export declare function withAuth<E extends any, T extends any>(cb: (event: E & ExtendedEvent) => T | Promise<T>): (event: E) => Promise<T>;
