import { getConfig } from '../config.js';
import { supabaseServerClient } from './supabaseServerClient.js';
/**
 * Use this helper to authenticate load functions, actions and request-handlers
 *
 * @example
 * export const load = withAuth(({ session, getSupabaseClient }) => {
 *  if (!session) {
 *    throw redirect(303, '/signin');
 *  }
 *  const { data: profile } = getSupabaseClient()
 *    .from('profiles')
 *    .select()
 *    .eq('user_id', session.user.id);
 *
 *  return { profile }
 * })
 */
export function withAuth(cb) {
    async function handle(event) {
        let session = {};
        // ServerLoad, Action, RequestHander
        const requestEvent = event;
        if (typeof requestEvent.locals === 'object') {
            session = getConfig().getSessionFromLocals(requestEvent.locals);
        }
        // Load
        const loadEvent = event;
        if (typeof loadEvent.parent === 'function') {
            const parentData = (await loadEvent.parent());
            session = getConfig().getSessionFromPageData(parentData);
        }
        /*
         * We are wrapping the event in a proxy to intercept the getter
         * for session and getSupabaseClient. This is necessary as sveltekit
         * does not allow overwriting the session currently.
         *
         * TODO: maybe remove this for sveltekit 1.0
         */
        const eventProxy = new Proxy(event, {
            get(target, property, receiver) {
                if (property === 'getSupabaseClient')
                    return () => supabaseServerClient(session.accessToken);
                if (property === 'session') {
                    return session;
                }
                return Reflect.get(target, property, receiver);
            }
        });
        return cb(eventProxy);
    }
    return handle;
}
